==> custom_pages-v1.12.9.zip: custom_pages/messages/nl/template.php <==
<?php
return [
  '<strong>Add</strong> new {type} element' => '<strong>Voeg</strong> nieuw {type} element toe',
  '<strong>Confirm</strong> container item deletion' => '<strong>Bevestig</strong> het verwijderen van het containeritem',
  '<strong>Confirm</strong> content deletion' => '<strong>Bevestig</strong> het verwijderen van de inhoud',
  '<strong>Confirm</strong> element deletion' => '<strong>Bevestig</strong> het verwijderen van het element',
  '<strong>Copying</strong> {type}' => '<strong>Kopiëren</strong> {type}',
  '<strong>Creating</strong> new Template' => 'Een nieuwe sjabloon <strong>maken</strong>',
  '<strong>Edit</strong> element {name}' => '<strong>Bewerk</strong> element {name}',
  '<strong>Edit</strong> elements of {templateName}' => '<strong>Bewerk</strong> elementen van {templateName}',
  '<strong>Edit</strong> {templateName}' => '<strong>Bewerk</strong> {templateName}',
  '<strong>Editing:</strong> {templateName}' => '<strong>Bewerken:</strong> {templateName}',
  '<strong>Import</strong> Template' => 'Sjabloon <strong>importeren</strong>',
  '<strong>Viewing:</strong> {templateName}' => '<strong>Bekijken:</strong> {templateName}',
  'Action' => 'Actie',
  'Actions' => 'Acties',
  'Add Element' => 'Element toevoegen',
  'Allow multiple items?' => 'Meerdere items toestaan?',
  'Allow this layout in spaces' => 'Sta deze lay-out toe in Ruimtes',
  'Allowed Templates' => 'Toegestane sjablonen',
  'Are you sure you want to delete this container item?' => 'Weet u zeker dat u dit containeritem wilt verwijderen?',
  'Cannot add item {itemNumber} with template {template} because the container doesn\'t allow multiple items!' => 'Item {itemNumber} kan niet worden toegevoegd aan sjabloon {template} omdat de container meerdere items niet toestaat!',
  'Cannot import container item {itemNumber} with template {template}!' => 'Kan containeritem {itemNumber} niet importeren met sjabloon {template}!',
  'Cannot import default template!' => 'Kan standaard sjabloon niet importeren!',
  'Cannot import element {element} of the template {template}!' => 'Kan element {element} van de sjabloon {template} niet importeren!',
  'Choose a template' => 'Kies een sjabloon',
  'Container' => 'Container',
  'Content' => 'Inhoud',
  'Content ID can be found in a permalink.' => 'De Inhoud-ID is te vinden in een permanente link.',
  'Copied' => 'Gekopieerd',
  'Copy' => 'Kopiëren',
  'Custom page supports only single template instance for importing!.' => 'Aangepaste pagina ondersteunt slechts één sjablooninstantie voor import!',
  'Define general settings for the template.' => 'Algemene instellingen voor de sjabloon definiëren.',
  'Define template layouts and add content elements with default content and settings.' => 'Definieer sjabloonindelingen en voeg inhoudselementen toe met standaardinhoud en -instellingen.',
  'Define template resources.' => 'Definieer sjabloonbronnen.',
  'Delete' => 'Verwijderen',
  'Description' => 'Beschrijving',
  'Do you really want to delete this content?' => 'Wilt u deze inhoud echt verwijderen?',
  'Do you really want to delete this element? <br />The deletion will affect all pages using this template.' => 'Wilt u dit element echt verwijderen?<br/>De verwijdering is van invloed op alle pagina\'s die deze sjabloon gebruiken.',
  'Edit' => 'Bewerken',
  'Edit Page' => 'Pagina bewerken',
  'Edit all elements' => 'Bewerk alle elementen',
  'Edit template' => 'Sjabloon bewerken',
  'Element "{name}" cannot be used as container!' => 'Element "{name}" kan niet als container worden gebruikt!',
  'Expire Time (in seconds)' => 'Vervaltijd (in seconden)',
  'Export' => 'Export',
  'File' => 'Bestand',
  'File Download' => 'Bestand downloaden',
  'File with template instance data in JSON format.' => 'Bestand met sjablooninstantiegegevens in JSON-formaat.',
  'Height' => 'Hoogte',
  'Here you can review where the template is used in.' => 'Hier kunt u zien waar de sjabloon voor wordt gebruikt.',
  'Html' => 'Html',
  'If a template with the same name already exists, it will be replaced with the data from your import file.' => 'Als er al een sjabloon met dezelfde naam bestaat, wordt deze vervangen door de gegevens uit uw importbestand.',
  'Image' => 'Afbeelding',
  'Import' => 'Importeren',
  'Import a template instance' => 'Een sjablooninstantie importeren',
  'Imported.' => 'Geïmporteerd.',
  'Is inline text' => 'Is inline tekst',
  'JavaScript' => 'JavaScript',
  'Label' => 'Label',
  'Leave blank to don\'t cache.' => 'Laat dit leeg om de cache niet te activeren.',
  'Leave blank to don\'t limit.' => 'Laat dit veld leeg als u geen limiet wilt instellen.',
  'Limit' => 'Beperken',
  'Limit items' => 'Beperk items',
  'Markdown' => 'Markdown',
  'Member' => 'Lid',
  'Mismatch number of elements for the template "{name}"!' => 'Aantal elementen voor de sjabloon "{name}" komt niet overeen!',
  'Move Down' => 'Omlaag verplaatsen',
  'Move Up' => 'Omhoog verplaatsen',
  'Name' => 'Naam',
  'Not member' => 'Geen lid',
  'Placeholder' => 'Tijdelijke aanduiding',
  'RSS feed URL' => 'RSS-feed-URL',
  'Replace existing children' => 'Vervang bestaande kinderen',
  'Reset' => 'Reset',
  'Rss' => 'RSS',
  'Search by template ID or name' => 'Zoeken op sjabloon-ID of naam',
  'Select group' => 'Selecteer groep',
  'Select space' => 'Selecteer ruimte',
  'Select spaces' => 'Selecteer ruimten',
  'Select user' => 'Selecteer gebruiker',
  'Select users' => 'Selecteer gebruikers',
  'Show less' => 'Laat minder zien',
  'Show more' => 'Laat meer zien',
  'Source' => 'Bron',
  'Space' => 'Ruimte',
  'Space member type' => 'Ruimtelidtype',
  'Spaces' => 'Ruimten',
  'Spaces where the user is' => 'Ruimtes waar de gebruiker lid van is',
  'Spaces with a specific tag' => 'Ruimten met een specifiek label',
  'Static list' => 'Statische lijst',
  'Structure View' => 'Structuurweergave',
  'Style' => 'Stijl',
  'Stylesheet' => 'Stylesheet',
  'Tag' => 'Label',
  'Template' => 'Sjabloon',
  'Template "{name}" has incompatible or missed elements {elements}!' => 'Sjabloon "{name}" bevat incompatibele of ontbrekende elementen {elements}!',
  'Template "{name}" is not allowed for the selected instance!' => 'Sjabloon "{name}" is niet toegestaan ​​voor de geselecteerde instantie!',
  'Template "{name}" is not found in system!' => 'Sjabloon "{name}" is niet gevonden in het systeem!',
  'Template element is not found!' => 'Sjabloonelement is niet gevonden!',
  'Template instance is not found!' => 'Sjablooninstantie is niet gevonden!',
  'Template instances are not found in the JSON file!' => 'Er zijn geen sjablooninstanties gevonden in het JSON-bestand!',
  'Template is not defined!' => 'Sjabloon is niet gedefinieerd!',
  'Template not found!' => 'Sjabloon niet gevonden!',
  'Text' => 'Tekst',
  'The container supports only single template instance for importing!.' => 'De container ondersteunt slechts één sjablooninstantie voor importeren!',
  'The template could not be deleted, please get sure that this template is not in use.' => 'De sjabloon kan niet worden verwijderd. Controleer of deze sjabloon in gebruik is.',
  'This is a default system template and cannot be modified. To make changes, please create a copy.' => 'Dit is een standaard systeemsjabloon en kan niet worden gewijzigd. Om wijzigingen aan te brengen, kunt u een kopie maken.',
  'Type' => 'Type',
  'Type (All)' => 'Type (Alles)',
  'Upload Template' => 'Sjabloon uploaden',
  'Upload a JSON file containing your template source data.' => 'Upload een JSON-bestand met de brongegevens van uw sjabloon.',
  'Upload file' => 'Bestand uploaden',
  'Usage' => 'Gebruik',
  'User' => 'Gebruiker',
  'Users' => 'Gebruikers',
  'Users from the selected group' => 'Gebruikers uit de geselecteerde groep',
  'Users where the user is friend of' => 'Gebruikers waarbij de gebruiker een vriend is van',
  'Version {version} is required for importing JSON file.' => 'Versie {version} is vereist voor het importeren van een JSON-bestand.',
  'View' => 'Weergave',
  'When no user is selected, the current logged in user will be used.' => 'Als er geen gebruiker is geselecteerd, wordt de op dat moment aangemelde gebruiker gebruikt.',
  'Width' => 'Breedte',
  'Wrong import data!' => 'Verkeerde importgegevens!',
  'You haven\'t saved your last changes yet. Do you want to leave without saving?' => 'U hebt de laatste wijzigingen nog niet opgeslagen. Wilt doorgaan zonder de wijzigingen op te slaan?',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/nl/template.php <==
<?php
return [
  '<strong>Add</strong> new {type} element' => '<strong>Voeg</strong> nieuw {type} element toe',
  '<strong>Confirm</strong> container item deletion' => '<strong>Bevestig</strong> het verwijderen van het containeritem',
  '<strong>Confirm</strong> content deletion' => '<strong>Bevestig</strong> het verwijderen van de inhoud',
  '<strong>Confirm</strong> element deletion' => '<strong>Bevestig</strong> het verwijderen van het element',
  '<strong>Copying</strong> {type}' => '<strong>Kopiëren</strong> {type}',
  '<strong>Creating</strong> new Template' => 'Een nieuwe sjabloon <strong>maken</strong>',
  '<strong>Edit</strong> element {name}' => '<strong>Bewerk</strong> element {name}',
  '<strong>Edit</strong> elements of {templateName}' => '<strong>Bewerk</strong> elementen van {templateName}',
  '<strong>Edit</strong> {templateName}' => '<strong>Bewerk</strong> {templateName}',
  '<strong>Editing:</strong> {templateName}' => '<strong>Bewerken:</strong> {templateName}',
  '<strong>Import</strong> Template' => 'Sjabloon <strong>importeren</strong>',
  '<strong>Viewing:</strong> {templateName}' => '<strong>Bekijken:</strong> {templateName}',
  'Action' => 'Actie',
  'Actions' => 'Acties',
  'Add Element' => 'Element toevoegen',
  'Allow multiple items?' => 'Meerdere items toestaan?',
  'Allow this layout in spaces' => 'Sta deze lay-out toe in Ruimtes',
  'Allowed Templates' => 'Toegestane sjablonen',
  'Are you sure you want to delete this container item?' => 'Weet u zeker dat u dit containeritem wilt verwijderen?',
  'Cannot add item {itemNumber} with template {template} because the container doesn\'t allow multiple items!' => 'Item {itemNumber} kan niet worden toegevoegd aan sjabloon {template} omdat de container meerdere items niet toestaat!',
  'Cannot import container item {itemNumber} with template {template}!' => 'Kan containeritem {itemNumber} niet importeren met sjabloon {template}!',
  'Cannot import default template!' => 'Kan standaard sjabloon niet importeren!',
  'Cannot import element {element} of the template {template}!' => 'Kan element {element} van de sjabloon {template} niet importeren!',
  'Choose a template' => 'Kies een sjabloon',
  'Container' => 'Container',
  'Content' => 'Inhoud',
  'Content ID can be found in a permalink.' => 'De Inhoud-ID is te vinden in een permanente link.',
  'Copied' => 'Gekopieerd',
  'Copy' => 'Kopiëren',
  'Custom page supports only single template instance for importing!.' => 'Aangepaste pagina ondersteunt slechts één sjablooninstantie voor import!',
  'Default' => 'Standaard',
  'Define general settings for the template.' => 'Algemene instellingen voor de sjabloon definiëren.',
  'Define template layouts and add content elements with default content and settings.' => 'Definieer sjabloonindelingen en voeg inhoudselementen toe met standaardinhoud en -instellingen.',
  'Define template resources.' => 'Definieer sjabloonbronnen.',
  'Delete' => 'Verwijderen',
  'Description' => 'Beschrijving',
  'Do you really want to delete this content?' => 'Wilt u deze inhoud echt verwijderen?',
  'Do you really want to delete this element? <br />The deletion will affect all pages using this template.' => 'Wilt u dit element echt verwijderen?<br/>De verwijdering is van invloed op alle pagina\'s die deze sjabloon gebruiken.',
  'Edit' => 'Bewerken',
  'Edit Page' => 'Pagina bewerken',
  'Edit all elements' => 'Bewerk alle elementen',
  'Edit template' => 'Sjabloon bewerken',
  'Element "{name}" cannot be used as container!' => 'Element "{name}" kan niet als container worden gebruikt!',
  'Expire Time (in seconds)' => 'Vervaltijd (in seconden)',
  'Export' => 'Export',
  'File' => 'Bestand',
  'File Download' => 'Bestand downloaden',
  'File with template instance data in JSON format.' => 'Bestand met sjablooninstantiegegevens in JSON-formaat.',
  'Height' => 'Hoogte',
  'Here you can review where the template is used in.' => 'Hier kunt u zien waar de sjabloon voor wordt gebruikt.',
  'Html' => 'Html',
  'If a template with the same name already exists, it will be replaced with the data from your import file.' => 'Als er al een sjabloon met dezelfde naam bestaat, wordt deze vervangen door de gegevens uit uw importbestand.',
  'Image' => 'Afbeelding',
  'Import' => 'Importeren',
  'Import a template instance' => 'Een sjablooninstantie importeren',
  'Imported.' => 'Geïmporteerd.',
  'Is inline text' => 'Is inline tekst',
  'JavaScript' => 'JavaScript',
  'Label' => 'Label',
  'Leave blank to don\'t cache.' => 'Laat dit leeg om de cache niet te activeren.',
  'Leave blank to don\'t limit.' => 'Laat dit veld leeg als u geen limiet wilt instellen.',
  'Limit' => 'Beperken',
  'Limit items' => 'Beperk items',
  'Markdown' => 'Markdown',
  'Member' => 'Lid',
  'Mismatch number of elements for the template "{name}"!' => 'Aantal elementen voor de sjabloon "{name}" komt niet overeen!',
  'Modules' => 'Modules',
  'Move Down' => 'Omlaag verplaatsen',
  'Move Up' => 'Omhoog verplaatsen',
  'Name' => 'Naam',
  'Next' => 'Volgende',
  'Not member' => 'Geen lid',
  'Placeholder' => 'Tijdelijke aanduiding',
  'RSS feed URL' => 'RSS-feed-URL',
  'Replace existing children' => 'Vervang bestaande kinderen',
  'Reset' => 'Reset',
  'Rss' => 'RSS',
  'Search by template ID or name' => 'Zoeken op sjabloon-ID of naam',
  'Select group' => 'Selecteer groep',
  'Select new element type' => 'Selecteer een nieuw elementtype',
  'Select space' => 'Selecteer ruimte',
  'Select spaces' => 'Selecteer ruimten',
  'Select user' => 'Selecteer gebruiker',
  'Select users' => 'Selecteer gebruikers',
  'Show less' => 'Laat minder zien',
  'Show more' => 'Laat meer zien',
  'Source' => 'Bron',
  'Space' => 'Ruimte',
  'Space member type' => 'Ruimtelidtype',
  'Spaces' => 'Ruimten',
  'Spaces where the user is' => 'Ruimtes waar de gebruiker lid van is',
  'Spaces with a specific tag' => 'Ruimten met een specifiek label',
  'Static list' => 'Statische lijst',
  'Structure View' => 'Structuurweergave',
  'Style' => 'Stijl',
  'Stylesheet' => 'Stylesheet',
  'Tag' => 'Label',
  'Template' => 'Sjabloon',
  'Template "{name}" has incompatible or missed elements {elements}!' => 'Sjabloon "{name}" bevat incompatibele of ontbrekende elementen {elements}!',
  'Template "{name}" is not allowed for the selected instance!' => 'Sjabloon "{name}" is niet toegestaan ​​voor de geselecteerde instantie!',
  'Template "{name}" is not found in system!' => 'Sjabloon "{name}" is niet gevonden in het systeem!',
  'Template element is not found!' => 'Sjabloonelement is niet gevonden!',
  'Template instance is not found!' => 'Sjablooninstantie is niet gevonden!',
  'Template instances are not found in the JSON file!' => 'Er zijn geen sjablooninstanties gevonden in het JSON-bestand!',
  'Template is not defined!' => 'Sjabloon is niet gedefinieerd!',
  'Template not found!' => 'Sjabloon niet gevonden!',
  'Text' => 'Tekst',
  'The container supports only single template instance for importing!.' => 'De container ondersteunt slechts één sjablooninstantie voor importeren!',
  'The template could not be deleted, please get sure that this template is not in use.' => 'De sjabloon kan niet worden verwijderd. Controleer of deze sjabloon in gebruik is.',
  'This is a default system template and cannot be modified. To make changes, please create a copy.' => 'Dit is een standaard systeemsjabloon en kan niet worden gewijzigd. Om wijzigingen aan te brengen, kunt u een kopie maken.',
  'Type' => 'Type',
  'Type (All)' => 'Type (Alles)',
  'Upload Template' => 'Sjabloon uploaden',
  'Upload a JSON file containing your template source data.' => 'Upload een JSON-bestand met de brongegevens van uw sjabloon.',
  'Upload file' => 'Bestand uploaden',
  'Usage' => 'Gebruik',
  'User' => 'Gebruiker',
  'Users' => 'Gebruikers',
  'Users from the selected group' => 'Gebruikers uit de geselecteerde groep',
  'Users where the user is friend of' => 'Gebruikers waarbij de gebruiker een vriend is van',
  'Version {version} is required for importing JSON file.' => 'Versie {version} is vereist voor het importeren van een JSON-bestand.',
  'View' => 'Weergave',
  'When no user is selected, the current logged in user will be used.' => 'Als er geen gebruiker is geselecteerd, wordt de op dat moment aangemelde gebruiker gebruikt.',
  'Width' => 'Breedte',
  'Wrong import data!' => 'Verkeerde importgegevens!',
  'You haven\'t saved your last changes yet. Do you want to leave without saving?' => 'U hebt de laatste wijzigingen nog niet opgeslagen. Wilt doorgaan zonder de wijzigingen op te slaan?',
];
